@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-$VERSION = '0.71';
+$VERSION = '0.76';
 
 use strict;
 use Config;
@@ -10,12 +10,13 @@ use ExtUtils::MakeMaker;
 use subs qw( _name _modtree );
 
 my %opts;
-getopts('BVxce:', \%opts);
+getopts('BVRxce:', \%opts);
 
 my (%map, %skip);
 my $core    = $opts{B};
 my $verbose = $opts{V};
 my $eval    = $opts{e};
+my $recurse = $opts{R} ? 0 : 1;
 
 if ($eval) {
     require File::Temp;
@@ -25,7 +26,7 @@ if ($eval) {
     push @ARGV, $filename;
 }
 
-die "Usage: $0 [ -B ] [ -V ] [ -x | -c ] [ -e STRING | FILE ... ]\n" unless @ARGV;
+die "Usage: $0 [ -B ] [ -V ] [ -x | -c ] [ -R ] [ -e STRING | FILE ... ]\n" unless @ARGV;
 
 my @files = @ARGV;
 while (<>) {
@@ -35,7 +36,7 @@ while (<>) {
 
 my $map = scan_deps(
     files   => \@files,
-    recurse => 1,
+    recurse => $recurse,
     $opts{x} ? ( execute => 1 ) :
     $opts{c} ? ( compile => 1 ) : (),
     $opts{V} ? ( warn_missing => 1 ) : (),
@@ -53,24 +54,28 @@ foreach my $key (sort keys %$map) {
     print "# $key [$mod->{type}]\n" if $verbose;
 
     if ($mod->{type} eq 'shared') {
-	$key =~ s!auto/!!;
-	$key =~ s!/[^/]+$!!;
-	$key =~ s!/!::!;
-	$bin{$key}++;
+        $key =~ s!auto/!!;
+        $key =~ s!/[^/]+$!!;
+        $key =~ s!/!::!;
+        $bin{$key}++;
     }
 
     next unless $mod->{type} eq 'module';
 
     next if $skip{$name};
 
-    if ($mod->{file} eq "$Config::Config{privlib}/$key"
-	or $mod->{file} eq "$Config::Config{archlib}/$key") {
-	next unless $core;
+    my $privPath = "$Config::Config{privlibexp}/$key";
+    my $archPath = "$Config::Config{archlibexp}/$key";
+    $privPath =~ s|\\|\/|og;
+    $archPath =~ s|\\|\/|og;
+    if ($mod->{file} eq $privPath
+        or $mod->{file} eq $archPath) {
+        next unless $core;
 
-	$core{$name}++;
+        $core{$name}++;
     }
     elsif (my $dist = _modtree->{$name}) {
-	$seen{$name} = $dist{$dist->package}++;
+        $seen{$name} = $dist{$dist->package}++;
     }
 
     $len = length($name) if $len < length($name);
@@ -95,9 +100,9 @@ foreach my $mod (sort {
     } else {
         printf "%-${len}s => '0', # ", "'$mod->{name}'";
         my @base = map(_name($_), @{$mod->{used_by}});
-        print $seen{$mod->{name}}	? 'S' : ' ';
-        print $bin{$mod->{name}}	? 'X' : ' ';
-        print $core{$mod->{name}}	? 'C' : ' ';
+        print $seen{$mod->{name}} ? 'S' : ' ';
+        print $bin{$mod->{name}}  ? 'X' : ' ';
+        print $core{$mod->{name}} ? 'C' : ' ';
         print _modtree && !_modtree->{$mod->{name}} ? '?' : ' ';
         print " # ";
         print "@base" if @base;
@@ -135,10 +140,11 @@ scandeps.pl - Scan file prerequisites
 
 =head1 SYNOPSIS
 
-    % scandeps.pl *.pm		# Print PREREQ_PM section for *.pm
+    % scandeps.pl *.pm          # Print PREREQ_PM section for *.pm
     % scandeps.pl -e 'STRING'	# Scan an one-liner
-    % scandeps.pl -B *.pm	# Include core modules
-    % scandeps.pl -V *.pm	# Show autoload/shared/data files
+    % scandeps.pl -B *.pm       # Include core modules
+    % scandeps.pl -V *.pm       # Show autoload/shared/data files
+    % scandeps.pl -R *.pm       # Don't recurse
 
 =head1 DESCRIPTION
 
@@ -183,6 +189,10 @@ Executes the code and inspects its C<%INC>, in addition to static scanning.
 
 Include core modules in the output and the recursive search list.
 
+=item -R
+
+Only show dependencies found in the files listed and do not recurse.
+
 =item -V
 
 Verbose mode: Output all files found during the process; 
